Page 38 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 38

Home

    Lately, we have got possession of the Bartholomew
    Institution for young clergymen, having secured all its
    supporters. Through this we shall be able to supply
    Bavaria with fit priests.’°

    Those who were willing to become tools of the Order
    were rewarded for their mindless obedience to their

    The power of the Order must surely be turned to the
    advantage of its Members. All must be assisted. They
    must be preferred to all persons otherwise of equal merit.
    Money, services, honor, goods, and blood, must be
    expended for the fully proved Brethren, and the
    unfortunate must be relieved by the funds of the
    Society."

    Thus the conspirators lived well while the fruits of
    their labor culminated in heartache, poverty, and every
    form of human suffering for the unfortunate souls living
    through the wars, revolutions, unrest, and turmoil created
    by these self-appointed perpetrators of "happiness for the
    human race."

    33

    The Illuminati

    unknown superiors by the following policy: